###################################################################################################################################################
# Sample script to create IC Assembly records
###################################################################################################################################################
# Copyright 2023 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
###################################################################################################################################################

from accpac import *

import time
import datetime
import subprocess

from ICAssembly import ICAssembly
from datetime import date, datetime, timedelta

# function uses the helper class to access all the composed views without having to compose them yourself
def createAssembly():
	showTrace("createAssembly")
	global vOEORDD
	global icassem

	# find O/E detail line.
	if vOEORDD == None:
		return

#	try:
	if icassem == None:
		icassem = ICAssembly()

	qtyOrdered = float(vOEORDD.get("QTYORDERED"))

	# create the assembly:
	icassem.icasen.order(0)
	icassem.icasen.put("ASSMENSEQ", "0")
	
	r = icassem.icasen.init()
	if r == 0:
		r = icassem.icasen.order(5)
	if r == 0:
		r = icassem.icasen.put("TRANSTYPE", 1)

	now = datetime.now()
	rightnow = datetime.strftime(now, "%Y%m%d")
	if r == 0:
		r = icassem.icasen.put("TRANSDATE", rightnow)

	if r == 0:
		item = vOEORDD.get("UNFMTITEM").strip()
		r = icassem.icasen.put("ITEMNO", item)

	# BOM Number.
	if r == 0:
		# get bom from detail line:
		#ddtlno = vOEORDD.get("DDTLNO").strip()
		ddtlno = "1"
		r = icassem.icasen.put("BOMNO", ddtlno)
	if r == 0:
		r = icassem.icasen.put("PROCESSCMD", 1)

	# reference
	if r == 0:
		r = icassem.icasen.put("REFERENCE", me.get("ORDNUMBER").strip())

	# description
	if r == 0:
		r = icassem.icasen.put("HDRDESC", me.get("DESC").strip())

	if r == 0:
		r = icassem.icasen.process()

	if r == 0:
		r = icassem.icasen.put("COMPASSMTD", 1)

	if r == 0:
		loc = vOEORDD.get("LOCATION").strip()
		r = icassem.icasen.put("LOCATION", loc)

	if r == 0:
		showTrace("Qty assembled: " + str(qtyOrdered))
		r = icassem.icasen.put("QUANTITY", str(qtyOrdered))

	if r == 0:
		showTrace("insert the assembly")
		r = icassem.icasen.insert()

	assemblyNum = ""
	if r != 0:
		showMessageBox("Unable to create BOM assembly for item [" + vOEORDD.get("ITEM").strip()+ "]")
	else:
		assemblyNum = icassem.icasen.get("DOCNUM").strip()
		showTrace(assemblyNum)

	return r, assemblyNum

